==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmă</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Șterge de pe desktop</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Îndepărtare din suportul de andocare</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Dezinstalare</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Deshide</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafică</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Joc</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Office</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Citește</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Elaborare</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Alții</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation> Toate dependenţele vor fi îndepărtate</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmă</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocare</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocare</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmare</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Niciun rezultat la căutare</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafică</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Birou</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Pentru citit</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Dezvoltare</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jocuri</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altul</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmă</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Îndepărtare de pe desktop</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Îndepărtare din suportul de andocare</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Dezinstalare</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Dezactivați redimensionarea afișajului</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deshide</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Trimite pe desktop</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Trimite în suportul de andocare</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Dezactivați deschiderea automată la pornirea sistemului</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Activați deschiderea automată la pornirea sistemului</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Toate aplicațiile</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafică</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Joc</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Office</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Citește</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Elaborare</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Alții</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoclipuri</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagini</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocare</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Repornire</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocare</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Repornire</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoclipuri</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagini</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoclipuri</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagini</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Toate categoriile</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmare</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
